@@ -171,6 +171,7 @@ def init_api_context(use_mamba_experimental=False):
     api_ctx.max_retries = context.remote_max_retries
     api_ctx.retry_backoff = context.remote_backoff_factor
     api_ctx.add_pip_as_python_dependency = context.add_pip_as_python_dependency
+    api_ctx.use_only_tar_bz2 = context.use_only_tar_bz2
 
 
 def to_package_record_from_subjson(channel, pkg, jsn_string):
@@ -203,6 +204,7 @@ def get_installed_packages(prefix, show_channel_urls=None):
     for prec in installed:
         json_rec = prec.dist_fields_dump()
         json_rec["depends"] = prec.depends
+        json_rec["constrains"] = prec.constrains
         json_rec["build"] = prec.build
         result["packages"][prec.fn] = json_rec
 
